Edviron class
Constructors
- Edviron({EdvironMode mode = EdvironMode.development})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- mode → EdvironMode
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
collect(
{required BuildContext context, required String collectRequestId, required void onSuccess(String collectRequestId), required VoidCallback onError}) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited